@@ -8,6 +8,7 @@
 # Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
 # Copyright (c) 2018 Anthony Sottile <asottile@umich.edu>
 # Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2021 Andrew Haigh <hello@nelf.in>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
@@ -18,10 +19,10 @@
 The builder is not thread safe and can't be used to parse different sources
 at the same time.
 """
-
 import os
 import textwrap
 from tokenize import detect_encoding
+from typing import List, Union
 
 from astroid import (
     bases,
@@ -34,6 +35,7 @@ from astroid import (
     util,
 )
 from astroid._ast import get_parser_module
+from astroid.node_classes import NodeNG
 
 objects = util.lazy_import("objects")
 
@@ -66,7 +68,7 @@ def _can_assign_attr(node, attrname):
     else:
         if slots and attrname not in {slot.value for slot in slots}:
             return False
-    return True
+    return node.qname() != "builtins.object"
 
 
 class AstroidBuilder(raw_building.InspectBuilder):
@@ -202,7 +204,9 @@ class AstroidBuilder(raw_building.InspectBuilder):
 
         Resort the locals if coming from a delayed node
         """
-        _key_func = lambda node: node.fromlineno
+
+        def _key_func(node):
+            return node.fromlineno
 
         def sort_locals(my_list):
             my_list.sort(key=_key_func)
@@ -357,7 +361,7 @@ def _find_statement_by_line(node, line):
     return None
 
 
-def extract_node(code, module_name=""):
+def extract_node(code: str, module_name: str = "") -> Union[NodeNG, List[NodeNG]]:
     """Parses some Python code as a module and extracts a designated AST node.
 
     Statements:
@@ -409,7 +413,6 @@ def extract_node(code, module_name=""):
     a module. Will be passed through textwrap.dedent first.
     :param str module_name: The name of the module.
     :returns: The designated node from the parse tree, or a list of nodes.
-    :rtype: astroid.bases.NodeNG, or a list of nodes.
     """
 
     def _extract(node):
